@@ -158,6 +158,8 @@ class DateEntry(Frame):
         except Exception as e:
             print(e)
             self.startdate = datetime.today()
+            self.entry.delete(0, 'end')
+            self.entry.insert('end', self.startdate.strftime(self.dateformat))
         olddate = datetime.strptime(self.entry.get() or self.startdate, self.dateformat)
         newdate = ask_date(self.entry, startdate=olddate, firstweekday=self.firstweekday, style=self.base_style)
         self.entry.delete('0', 'end')
@@ -264,7 +266,7 @@ class DateChooserPopup:
 
         # month and year title
         self.title_label = ttk.Label(self.tframe, textvariable=self.titlevar, anchor='center')
-        self.title_label.configure(style=self.styles['title'], font='helvetica 11')
+        self.title_label.configure(style=self.styles['title'])
         self.title_label.pack(side='left', fill='x', expand='yes')
         self.title_label.bind('<Button-1>', self.on_reset_date)
 
